summaryrefslogtreecommitdiff
path: root/src/ext-proxy.c
diff options
context:
space:
mode:
authorrafa_99 <raroma09@gmail.com>2021-09-25 01:23:25 +0100
committerrafa_99 <raroma09@gmail.com>2021-09-25 01:23:25 +0100
commitb1518d7d72421cae4b157943dd07e2030a918289 (patch)
treeb882d71068852d0de1841b70e68a1ed104e640b4 /src/ext-proxy.c
parentbc11211ffb6ecc5bed00f144ab03cd8c770035a5 (diff)
Project branch off
Diffstat (limited to 'src/ext-proxy.c')
-rw-r--r--src/ext-proxy.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ext-proxy.c b/src/ext-proxy.c
index 84ab325..612f6e8 100644
--- a/src/ext-proxy.c
+++ b/src/ext-proxy.c
@@ -46,9 +46,9 @@ static void on_web_extension_page_created(GDBusConnection *connection,
GVariant *parameters, gpointer data);
/* TODO we need potentially multiple proxies. Because a single instance of
* vimb may hold multiple clients which may use more than one webprocess and
* therefore multiple webextension instances. */
-extern struct Vimb vb;
+extern struct neovimb vb;
static GDBusServer *dbusserver;
@@ -46,9 +46,9 @@ static void on_web_extension_page_created(GDBusConnection *connection,
GVariant *parameters, gpointer data);
/* TODO we need potentially multiple proxies. Because a single instance of
- * vimb may hold multiple clients which may use more than one webprocess and
+ * neovimb may hold multiple clients which may use more than one webprocess and
* therefore multiple webextension instances. */